@@ -36,6 +36,7 @@ class CogniteClient:
         max_workers (int): Max number of workers to spawn when parallelizing data fetching. Defaults to 10.
         headers (Dict): Additional headers to add to all requests.
         timeout (int): Timeout on requests sent to the api. Defaults to 30 seconds.
+        file_transfer_timeout (int): Timeout on file upload/download requests. Defaults to 600 seconds.
         proxies (Dict[str, str]): Dictionary mapping from protocol to url. e.g. {"https": "http://10.10.1.10:1080"}
         token (Union[str, Callable[[], str]]): A jwt or method which takes no arguments and returns a jwt to use for authentication.
             This will override any api-key set.
@@ -65,6 +66,7 @@ class CogniteClient:
         max_workers: Optional[int] = None,
         headers: Optional[Dict[str, str]] = None,
         timeout: Optional[int] = None,
+        file_transfer_timeout: Optional[int] = None,
         proxies: Optional[Dict[str, str]] = None,
         token: Optional[Union[str, Callable[[], str], None]] = None,
         token_url: Optional[str] = None,
@@ -84,6 +86,7 @@ class CogniteClient:
             max_workers=max_workers,
             headers=headers,
             timeout=timeout,
+            file_transfer_timeout=file_transfer_timeout,
             proxies=proxies,
             token=token,
             token_url=token_url,
